@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.15 2004/05/06 06:30:59 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.16 2004/05/11 09:27:14 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -105,7 +105,9 @@ typedef struct {
  */
 typedef struct {
 	int fd;
+#ifdef NOT_USED
 	FILE *read_fd;	/* stream read connection */
+#endif
 	FILE *write_fd;	/* stream write connection */
 	char *hp;	/* pending data buffer head address */
 	int po;		/* pending data offset */
