@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.16 2004/05/11 09:27:14 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.16.2.1 2004/05/16 03:27:32 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -1013,7 +1013,13 @@ static POOL_STATUS FunctionCall(POOL_CONNECTION *frontend,
 
 		free(arg);
 	}
-	return pool_flush(MASTER(backend));
+
+	if (pool_flush(MASTER(backend)))
+		return POOL_ERROR;
+	if (REPLICATION)
+		if (pool_flush(SECONDARY(backend)))
+			return POOL_ERROR;
+	return POOL_CONTINUE;
 }
 
 static POOL_STATUS FunctionResultResponse(POOL_CONNECTION *frontend, 
